Setup
============

Dependencies
------------

* numpy
* pandas (for importing data)
* numba
* scipy (for power analysis)

Installation
------------

The easiest way to install hierarch is via PyPi. ::

    pip install hierarch

Alternatively, you can install from Anaconda. ::

    conda install -c rkulk111 hierarch